<template>
  <a-spin :spinning="confirmLoading">
    <j-form-container :disabled="formDisabled">
      <a-form-model ref="form" :model="model" :rules="validatorRules" slot="detail">
        <a-row>
          <a-col :span="24">
            <a-form-model-item label="物料分类编码" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="code">
              <a-input v-model="model.code" placeholder="请输入物料分类编码"  :disabled="true"></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="物料分类名称" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="name">
              <a-input v-model="model.name" placeholder="请输入物料分类名称" ></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="上级分类" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="name">
              <a-input v-model="model.parentId" placeholder="系统自动判定生成" disabled></a-input>
            </a-form-model-item>
          </a-col>
          
          <a-col :span="24">
            <a-form-model-item label="版本状态" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="versionStatus">
              <a-input v-model="model.versionStatus" placeholder="系统自动判定生成" :disabled="true"></a-input>
            </a-form-model-item>
          </a-col>
          <!-- <a-col :span="24">
            <a-form-model-item label="状态" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="status">
              <a-radio-group  button-style="solid" v-model="model.status">
                <a-radio-button value='1' style="width:100px;text-align: center;">
                正 常
                </a-radio-button>
                <a-radio-button value='0' style="width:100px;text-align: center;">
                冻 结
                </a-radio-button>
              </a-radio-group>
            </a-form-model-item>
          </a-col> -->
          <a-col :span="24">
            <a-form-model-item label="备注" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="remark">
              <a-input v-model="model.remark" placeholder="请输入备注"  ></a-input>
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </j-form-container>
  </a-spin>
</template>
<script>
  import { httpAction, getAction } from '@/api/manage'
  import { validateDuplicateValue } from '@/utils/util'
import { putAction } from '../../../../api/manage'
  export default {
    name: 'EnterpriseForm',
    components: {
    },
    props: {
      //表单禁用
      disabled: {
        type: Boolean,
        default: false,
        required: false
      },
      version:{
        type:Number,
        required:false
      },
      parentId:{
        type:String,
        default:'',
        required:false
      },
      versionStatus:{
        type:String,
        default:'',
        required:false
      },
    },
    data () {
      return {
        codeRule:'mom_base_material_category_code_rule',
        tempVersionStatus:'',
        tempName:'',
        model:{
         },
        labelCol: {
          xs: { span: 24 },
          sm: { span: 5 },
        },
        wrapperCol: {
          xs: { span: 24 },
          sm: { span: 16 },
        },
        confirmLoading: false,
        validatorRules: {
          name:[
            {required:true,message:'请输入物料分类名称'},
            { validator:this.validateName},
            {min:0,max:32,message:'长度超出最大限制，请缩减长度'}
          ],
          code:[
            {required:true},
          ],
          remark:[
            {min:0,max:100,message:'长度超出最大限制，请缩减长度'}
          ],
          versionStatus:[{required:true}],
          status:[
            {required:true,message:'请选择状态'}
          ]
        },
        url: {
          add: "/base/materialCategory/add",
          edit: "/base/materialCategory/edit",
          queryById: "/base/materialCategory/queryById",
          check:"/base/materialCategory/check",
          ruleBaseURL:"/sys/fillRule/executeRuleByCode",
        }
      }
    },
    computed: {
      formDisabled(){
        return this.disabled
      },
    },
    created () {
       //备份model原始值
      this.modelDefault = JSON.parse(JSON.stringify(this.model));
    },
    methods: {
      add () {
        this.edit(this.modelDefault);
      },
      edit (record) {
        this.model = Object.assign({}, record);
        this.tempVersionStatus=this.model.versionStatus;
        this.model.versionStatus='';
        if(this.model.id){
          this.tempName=this.model.name;
        }
        this.visible = true;
        if(!this.model.id){
          var ruleCodeParam={
            parentId:this.parentId,
            version:this.version
          }
          putAction(this.url.ruleBaseURL+"/"+this.codeRule,ruleCodeParam).then(res=>{
            this.model.code=res.result;
          });
        }
      },
      submitForm () {
        const that = this;
        if(!this.model.id){
          this.model.versionStatus='0'
        }
        else{
          this.model.versionStatus=this.tempVersionStatus
        }
        // 触发表单验证
        this.$refs.form.validate(valid => {
          if (valid) {
            that.confirmLoading = true;
            let httpurl = '';
            let method = '';
            if(!this.model.id){
              httpurl+=this.url.add;
              method = 'post';
              this.model.parentId=this.parentId;
              if(this.version){
                this.model.version = this.version;
              }else{
                this.model.version = 1;
              } 
            }else{
              httpurl+=this.url.edit;
               method = 'put';
            }
            httpAction(httpurl,this.model,method).then((res)=>{
              if(res.success){
                that.$message.success(res.message);
                that.$emit('ok');
              }else{
                that.$message.warning(res.message);
              }
            }).finally(() => {
              this.$emit('reloadUi')
              that.confirmLoading = false;
            })
          }else{
            this.$emit("changeAddLoading")
            this.model.versionStatus='';
          }     
        })
      },
      validateName(rule, value, callback){
        var params = {
        name:value,
        version:this.version,
        parentId:this.parentId
      };
      getAction(this.url.check,params).then(res=>{
            if(res.result.length==0){
              callback();
            }
            else if(this.tempName==value){
              callback();
            }
            else{
              callback('企业名称重复，请重新输入')
            }
        })
      },
      clearInfo(){
        this.model.code=''
        var ruleCodeParam={
            version:this.version,
            parentId:this.parentId
        }
        putAction(this.url.ruleBaseURL+"/"+this.codeRule,ruleCodeParam).then(res=>{
            this.model.code=res.result;
            this.model.name='';
            this.model.status='';
            this.model.versionStatus=''
        });
      }
    }
  }
</script>